package com.interswitchng.isw_mobile_sdk;



import android.app.Application;
import com.interswitchng.iswmobilesdk.IswMobileSdk;
import com.interswitchng.iswmobilesdk.shared.models.core.Environment;
import com.interswitchng.iswmobilesdk.shared.models.core.IswPaymentInfo;
import com.interswitchng.iswmobilesdk.shared.models.core.IswPaymentResult;
import com.interswitchng.iswmobilesdk.shared.models.core.IswSdkConfig;

import java.util.HashMap;
import java.util.Map;


import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * IswMobileSdkPlugin
 */
public class IswMobileSdkPlugin implements MethodCallHandler {

    private static Application application;

    private IswMobileSdkPlugin() {}

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        switch (call.method) {
            case "initialize":
                Map<String, String> configMap = call.argument("config");
                String env = call.argument("env");
                assert configMap != null;
                assert env != null;

                IswMobileSdk.initialize(application, getConfig(configMap, env));
                result.success(null);
                break;
            case "pay":
                Map<String, String> infoMap = call.argument("paymentInfo");
                assert infoMap != null;
                IswMobileSdk.getInstance().pay(getPaymentInfo(infoMap), new IswSdkCallback(call, result));
                break;
            default:
                result.notImplemented();
        }
    }


    private IswSdkConfig getConfig(Map<String, String> configMap, String env) {
        // extract configurations
        String merchantId = configMap.get("merchantId"),
                merchantSecret = configMap.get("merchantSecret"),
                merchantCode = configMap.get("merchantCode"),
                currencyCode = configMap.get("currencyCode");

        boolean isProduction = env.equals(Environment.PRODUCTION.name());
        boolean isSandbox = env.equals(Environment.SANDBOX.name());

        // create configuration
        IswSdkConfig config = new IswSdkConfig(merchantId, merchantSecret, merchantCode, currencyCode);

        // set environment
        if (isProduction) config.setEnv(Environment.PRODUCTION);
        else if (isSandbox) config.setEnv(Environment.SANDBOX);


        return config;
    }

    private IswPaymentInfo getPaymentInfo(Map<String, String> infoMap) {

        String customerId = infoMap.get("customerId"),
                customerName = infoMap.get("customerName"),
                customerEmail = infoMap.get("customerEmail"),
                customerMobile = infoMap.get("customerMobile"),
                reference = infoMap.get("reference"),
                amount = infoMap.get("amount");

        return new IswPaymentInfo(customerId, customerName, customerEmail, customerMobile, reference, Integer.valueOf(amount));
    }


    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        application = registrar.activity().getApplication();

        final MethodChannel channel = new MethodChannel(registrar.messenger(), "com.interswitchng.isw_mobile_sdk");
        channel.setMethodCallHandler(new IswMobileSdkPlugin());
    }


    static class IswSdkCallback implements IswMobileSdk.IswPaymentCallback {
//        MethodCall call;
        Result result;
        public IswSdkCallback(MethodCall call, Result result) {
//            this.call = call;
            this.result = result;
        }

        @Override
        public void onUserCancel() {
            this.result.success(null);
        }

        @Override
        public void onPaymentCompleted(IswPaymentResult iswPaymentResult) {
            this.result.success(getResult(iswPaymentResult));
        }

        private Map<String, String> getResult(IswPaymentResult result) {
            Map<String, String> map = new HashMap<>();
            map.put("responseCode", result.responseCode);
            map.put("responseDescription", result.responseDescription);
            map.put("transactionReference", result.transactionReference);
            map.put("amount", result.amount + "");
            map.put("isSuccessful", result.isSuccessful + "");
            map.put("channel", result.channel.name());
            return map;
        }
    }
}
